ca_focus
open | /demo/ca_focus.html |
assertTextPresent | Focus on none. |
click | focus-to-text |
waitForTextPresent | Focus on text. |
assertTextPresent | Focus on text. |
click | focus-to-textarea |
waitForTextPresent | Focus on textarea. |
assertTextPresent | Focus on textarea. |
click | focus-to-select |
waitForTextPresent | Focus on select. |
assertTextPresent | Focus on select. |
click | focus-to-radio |
waitForTextPresent | Focus on radio-1. |
assertTextPresent | Focus on radio-1. |
click | focus-to-checkbox |
waitForTextPresent | Focus on checkbox-1. |
assertTextPresent | Focus on checkbox-1. |
click | server-focus-to-text |
waitForTextPresent | Focus on text. |
assertTextPresent | Focus on text. |
click | server-focus-to-textarea |
waitForTextPresent | Focus on textarea. |
assertTextPresent | Focus on textarea. |
click | server-focus-to-select |
waitForTextPresent | Focus on select. |
assertTextPresent | Focus on select. |
click | server-focus-to-radio |
waitForTextPresent | Focus on radio-1. |
assertTextPresent | Focus on radio-1. |
click | server-focus-to-checkbox |
waitForTextPresent | Focus on checkbox-1. |
assertTextPresent | Focus on checkbox-1. |